.. audtorch documentation master file

.. include:: ../README.rst
    :end-line: 31

.. toctree::
    :caption: Getting started

    install
    usage
    develop
    changelog

.. Warning: then usage of genindex is a hack to get a TOC entry, see
.. https://stackoverflow.com/a/42310803. This might break the usage of sphinx if
.. you want to create something different than HTML output.
.. toctree::
    :caption: API Documentation

    api-collate
    api-datasets
    api-metrics
    api-metrics-functional
    api-samplers
    api-transforms
    api-transforms-functional
    api-utils
    refs
    genindex
